Class: Aws::EventBridge::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::EventBridge::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-eventbridge/client.rb
Overview
An API client for EventBridge. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::EventBridge::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#activate_event_source(params = {}) ⇒ Struct
Activates a partner event source that has been deactivated.
-
#cancel_replay(params = {}) ⇒ Types::CancelReplayResponse
Cancels the specified replay.
-
#create_api_destination(params = {}) ⇒ Types::CreateApiDestinationResponse
Creates an API destination, which is an HTTP invocation endpoint configured as a target for events.
-
#create_archive(params = {}) ⇒ Types::CreateArchiveResponse
Creates an archive of events with the specified settings.
-
#create_connection(params = {}) ⇒ Types::CreateConnectionResponse
Creates a connection.
-
#create_endpoint(params = {}) ⇒ Types::CreateEndpointResponse
Creates a global endpoint.
-
#create_event_bus(params = {}) ⇒ Types::CreateEventBusResponse
Creates a new event bus within your account.
-
#create_partner_event_source(params = {}) ⇒ Types::CreatePartnerEventSourceResponse
Called by an SaaS partner to create a partner event source.
-
#deactivate_event_source(params = {}) ⇒ Struct
You can use this operation to temporarily stop receiving events from the specified partner event source.
-
#deauthorize_connection(params = {}) ⇒ Types::DeauthorizeConnectionResponse
Removes all authorization parameters from the connection.
-
#delete_api_destination(params = {}) ⇒ Struct
Deletes the specified API destination.
-
#delete_archive(params = {}) ⇒ Struct
Deletes the specified archive.
-
#delete_connection(params = {}) ⇒ Types::DeleteConnectionResponse
Deletes a connection.
-
#delete_endpoint(params = {}) ⇒ Struct
Delete an existing global endpoint.
-
#delete_event_bus(params = {}) ⇒ Struct
Deletes the specified custom event bus or partner event bus.
-
#delete_partner_event_source(params = {}) ⇒ Struct
This operation is used by SaaS partners to delete a partner event source.
-
#delete_rule(params = {}) ⇒ Struct
Deletes the specified rule.
-
#describe_api_destination(params = {}) ⇒ Types::DescribeApiDestinationResponse
Retrieves details about an API destination.
-
#describe_archive(params = {}) ⇒ Types::DescribeArchiveResponse
Retrieves details about an archive.
-
#describe_connection(params = {}) ⇒ Types::DescribeConnectionResponse
Retrieves details about a connection.
-
#describe_endpoint(params = {}) ⇒ Types::DescribeEndpointResponse
Get the information about an existing global endpoint.
-
#describe_event_bus(params = {}) ⇒ Types::DescribeEventBusResponse
Displays details about an event bus in your account.
-
#describe_event_source(params = {}) ⇒ Types::DescribeEventSourceResponse
This operation lists details about a partner event source that is shared with your account.
-
#describe_partner_event_source(params = {}) ⇒ Types::DescribePartnerEventSourceResponse
An SaaS partner can use this operation to list details about a partner event source that they have created.
-
#describe_replay(params = {}) ⇒ Types::DescribeReplayResponse
Retrieves details about a replay.
-
#describe_rule(params = {}) ⇒ Types::DescribeRuleResponse
Describes the specified rule.
-
#disable_rule(params = {}) ⇒ Struct
Disables the specified rule.
-
#enable_rule(params = {}) ⇒ Struct
Enables the specified rule.
-
#list_api_destinations(params = {}) ⇒ Types::ListApiDestinationsResponse
Retrieves a list of API destination in the account in the current Region.
-
#list_archives(params = {}) ⇒ Types::ListArchivesResponse
Lists your archives.
-
#list_connections(params = {}) ⇒ Types::ListConnectionsResponse
Retrieves a list of connections from the account.
-
#list_endpoints(params = {}) ⇒ Types::ListEndpointsResponse
List the global endpoints associated with this account.
-
#list_event_buses(params = {}) ⇒ Types::ListEventBusesResponse
Lists all the event buses in your account, including the default event bus, custom event buses, and partner event buses.
-
#list_event_sources(params = {}) ⇒ Types::ListEventSourcesResponse
You can use this to see all the partner event sources that have been shared with your Amazon Web Services account.
-
#list_partner_event_source_accounts(params = {}) ⇒ Types::ListPartnerEventSourceAccountsResponse
An SaaS partner can use this operation to display the Amazon Web Services account ID that a particular partner event source name is associated with.
-
#list_partner_event_sources(params = {}) ⇒ Types::ListPartnerEventSourcesResponse
An SaaS partner can use this operation to list all the partner event source names that they have created.
-
#list_replays(params = {}) ⇒ Types::ListReplaysResponse
Lists your replays.
-
#list_rule_names_by_target(params = {}) ⇒ Types::ListRuleNamesByTargetResponse
Lists the rules for the specified target.
-
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists your Amazon EventBridge rules.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Displays the tags associated with an EventBridge resource.
-
#list_targets_by_rule(params = {}) ⇒ Types::ListTargetsByRuleResponse
Lists the targets assigned to the specified rule.
-
#put_events(params = {}) ⇒ Types::PutEventsResponse
Sends custom events to Amazon EventBridge so that they can be matched to rules.
-
#put_partner_events(params = {}) ⇒ Types::PutPartnerEventsResponse
This is used by SaaS partners to write events to a customer’s partner event bus.
-
#put_permission(params = {}) ⇒ Struct
Running ‘PutPermission` permits the specified Amazon Web Services account or Amazon Web Services organization to put events to the specified *event bus*.
-
#put_rule(params = {}) ⇒ Types::PutRuleResponse
Creates or updates the specified rule.
-
#put_targets(params = {}) ⇒ Types::PutTargetsResponse
Adds the specified targets to the specified rule, or updates the targets if they are already associated with the rule.
-
#remove_permission(params = {}) ⇒ Struct
Revokes the permission of another Amazon Web Services account to be able to put events to the specified event bus.
-
#remove_targets(params = {}) ⇒ Types::RemoveTargetsResponse
Removes the specified targets from the specified rule.
-
#start_replay(params = {}) ⇒ Types::StartReplayResponse
Starts the specified replay.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified EventBridge resource.
-
#test_event_pattern(params = {}) ⇒ Types::TestEventPatternResponse
Tests whether the specified event pattern matches the provided event.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified EventBridge resource.
-
#update_api_destination(params = {}) ⇒ Types::UpdateApiDestinationResponse
Updates an API destination.
-
#update_archive(params = {}) ⇒ Types::UpdateArchiveResponse
Updates the specified archive.
-
#update_connection(params = {}) ⇒ Types::UpdateConnectionResponse
Updates settings for a connection.
-
#update_endpoint(params = {}) ⇒ Types::UpdateEndpointResponse
Update an existing endpoint.
-
#update_event_bus(params = {}) ⇒ Types::UpdateEventBusResponse
Updates the specified event bus.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4371 4372 4373 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 4371 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4374 4375 4376 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 4374 def errors_module Errors end |
Instance Method Details
#activate_event_source(params = {}) ⇒ Struct
Activates a partner event source that has been deactivated. Once activated, your matching event bus will start receiving events from the event source.
503 504 505 506 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 503 def activate_event_source(params = {}, = {}) req = build_request(:activate_event_source, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 4358 4359 4360 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 4344 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::EventBridge') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-eventbridge' context[:gem_version] = '1.100.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_replay(params = {}) ⇒ Types::CancelReplayResponse
Cancels the specified replay.
535 536 537 538 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 535 def cancel_replay(params = {}, = {}) req = build_request(:cancel_replay, params) req.send_request() end |
#create_api_destination(params = {}) ⇒ Types::CreateApiDestinationResponse
Creates an API destination, which is an HTTP invocation endpoint configured as a target for events.
API destinations do not support private destinations, such as interface VPC endpoints.
For more information, see [API destinations] in the *EventBridge User Guide*.
[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-api-destinations.html
603 604 605 606 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 603 def create_api_destination(params = {}, = {}) req = build_request(:create_api_destination, params) req.send_request() end |
#create_archive(params = {}) ⇒ Types::CreateArchiveResponse
Creates an archive of events with the specified settings. When you create an archive, incoming events might not immediately start being sent to the archive. Allow a short period of time for changes to take effect. If you do not specify a pattern to filter events sent to the archive, all events are sent to the archive except replayed events. Replayed events are not sent to an archive.
If you have specified that EventBridge use a customer managed key for encrypting the source event bus, we strongly recommend you also specify a customer managed key for any archives for the event bus as well.
For more information, see [Encrypting archives][1] in the *Amazon
EventBridge User Guide*.
[1]: docs.aws.amazon.com/eventbridge/latest/userguide/encryption-archives.html
697 698 699 700 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 697 def create_archive(params = {}, = {}) req = build_request(:create_archive, params) req.send_request() end |
#create_connection(params = {}) ⇒ Types::CreateConnectionResponse
Creates a connection. A connection defines the authorization type and credentials to use for authorization with an API destination HTTP endpoint.
For more information, see [Connections for endpoint targets] in the *Amazon EventBridge User Guide*.
[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-target-connection.html
860 861 862 863 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 860 def create_connection(params = {}, = {}) req = build_request(:create_connection, params) req.send_request() end |
#create_endpoint(params = {}) ⇒ Types::CreateEndpointResponse
Creates a global endpoint. Global endpoints improve your application’s availability by making it regional-fault tolerant. To do this, you define a primary and secondary Region with event buses in each Region. You also create a Amazon Route 53 health check that will tell EventBridge to route events to the secondary Region when an “unhealthy” state is encountered and events will be routed back to the primary Region when the health check reports a “healthy” state.
950 951 952 953 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 950 def create_endpoint(params = {}, = {}) req = build_request(:create_endpoint, params) req.send_request() end |
#create_event_bus(params = {}) ⇒ Types::CreateEventBusResponse
Creates a new event bus within your account. This can be a custom event bus which you can use to receive events from your custom applications and services, or it can be a partner event bus which can be matched to a partner event source.
1087 1088 1089 1090 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1087 def create_event_bus(params = {}, = {}) req = build_request(:create_event_bus, params) req.send_request() end |
#create_partner_event_source(params = {}) ⇒ Types::CreatePartnerEventSourceResponse
Called by an SaaS partner to create a partner event source. This operation is not used by Amazon Web Services customers.
Each partner event source can be used by one Amazon Web Services account to create a matching partner event bus in that Amazon Web Services account. A SaaS partner must create one partner event source for each Amazon Web Services account that wants to receive those event types.
A partner event source creates events based on resources within the SaaS partner’s service or application.
An Amazon Web Services account that creates a partner event bus that matches the partner event source can use that event bus to receive events from the partner, and then process them using Amazon Web Services Events rules and targets.
Partner event source names follow this format:
‘ partner_name/event_namespace/event_name `
-
partner_name is determined during partner registration, and identifies the partner to Amazon Web Services customers.
-
event_namespace is determined by the partner, and is a way for the partner to categorize their events.
-
event_name is determined by the partner, and should uniquely identify an event-generating resource within the partner system.
The event_name must be unique across all Amazon Web Services customers. This is because the event source is a shared resource between the partner and customer accounts, and each partner event source unique in the partner account.
The combination of event_namespace and event_name should help Amazon Web Services customers decide whether to create an event bus to receive these events.
1161 1162 1163 1164 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1161 def create_partner_event_source(params = {}, = {}) req = build_request(:create_partner_event_source, params) req.send_request() end |
#deactivate_event_source(params = {}) ⇒ Struct
You can use this operation to temporarily stop receiving events from the specified partner event source. The matching event bus is not deleted.
When you deactivate a partner event source, the source goes into PENDING state. If it remains in PENDING state for more than two weeks, it is deleted.
To activate a deactivated partner event source, use [ActivateEventSource].
[1]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_ActivateEventSource.html
1196 1197 1198 1199 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1196 def deactivate_event_source(params = {}, = {}) req = build_request(:deactivate_event_source, params) req.send_request() end |
#deauthorize_connection(params = {}) ⇒ Types::DeauthorizeConnectionResponse
Removes all authorization parameters from the connection. This lets you remove the secret from the connection so you can reuse it without having to create a new connection.
1234 1235 1236 1237 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1234 def (params = {}, = {}) req = build_request(:deauthorize_connection, params) req.send_request() end |
#delete_api_destination(params = {}) ⇒ Struct
Deletes the specified API destination.
1256 1257 1258 1259 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1256 def delete_api_destination(params = {}, = {}) req = build_request(:delete_api_destination, params) req.send_request() end |
#delete_archive(params = {}) ⇒ Struct
Deletes the specified archive.
1278 1279 1280 1281 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1278 def delete_archive(params = {}, = {}) req = build_request(:delete_archive, params) req.send_request() end |
#delete_connection(params = {}) ⇒ Types::DeleteConnectionResponse
Deletes a connection.
1314 1315 1316 1317 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1314 def delete_connection(params = {}, = {}) req = build_request(:delete_connection, params) req.send_request() end |
#delete_endpoint(params = {}) ⇒ Struct
Delete an existing global endpoint. For more information about global endpoints, see [Making applications Regional-fault tolerant with global endpoints and event replication] in the Amazon EventBridge User Guide .
[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-global-endpoints.html
1344 1345 1346 1347 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1344 def delete_endpoint(params = {}, = {}) req = build_request(:delete_endpoint, params) req.send_request() end |
#delete_event_bus(params = {}) ⇒ Struct
Deletes the specified custom event bus or partner event bus. All rules associated with this event bus need to be deleted. You can’t delete your account’s default event bus.
1368 1369 1370 1371 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1368 def delete_event_bus(params = {}, = {}) req = build_request(:delete_event_bus, params) req.send_request() end |
#delete_partner_event_source(params = {}) ⇒ Struct
This operation is used by SaaS partners to delete a partner event source. This operation is not used by Amazon Web Services customers.
When you delete an event source, the status of the corresponding partner event bus in the Amazon Web Services customer account becomes DELETED.
1400 1401 1402 1403 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1400 def delete_partner_event_source(params = {}, = {}) req = build_request(:delete_partner_event_source, params) req.send_request() end |
#delete_rule(params = {}) ⇒ Struct
Deletes the specified rule.
Before you can delete the rule, you must remove all targets, using [RemoveTargets].
When you delete a rule, incoming events might continue to match to the deleted rule. Allow a short period of time for changes to take effect.
If you call delete rule multiple times for the same rule, all calls will succeed. When you call delete rule for a non-existent custom eventbus, ‘ResourceNotFoundException` is returned.
Managed rules are rules created and managed by another Amazon Web Services service on your behalf. These rules are created by those other Amazon Web Services services to support functionality in those services. You can delete these rules using the ‘Force` option, but you should do so only if you are sure the other service is not still using that rule.
[1]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_RemoveTargets.html
1456 1457 1458 1459 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1456 def delete_rule(params = {}, = {}) req = build_request(:delete_rule, params) req.send_request() end |
#describe_api_destination(params = {}) ⇒ Types::DescribeApiDestinationResponse
Retrieves details about an API destination.
1502 1503 1504 1505 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1502 def describe_api_destination(params = {}, = {}) req = build_request(:describe_api_destination, params) req.send_request() end |
#describe_archive(params = {}) ⇒ Types::DescribeArchiveResponse
Retrieves details about an archive.
1552 1553 1554 1555 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1552 def describe_archive(params = {}, = {}) req = build_request(:describe_archive, params) req.send_request() end |
#describe_connection(params = {}) ⇒ Types::DescribeConnectionResponse
Retrieves details about a connection.
1635 1636 1637 1638 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1635 def describe_connection(params = {}, = {}) req = build_request(:describe_connection, params) req.send_request() end |
#describe_endpoint(params = {}) ⇒ Types::DescribeEndpointResponse
Get the information about an existing global endpoint. For more information about global endpoints, see [Making applications Regional-fault tolerant with global endpoints and event replication] in the Amazon EventBridge User Guide .
[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-global-endpoints.html
1702 1703 1704 1705 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1702 def describe_endpoint(params = {}, = {}) req = build_request(:describe_endpoint, params) req.send_request() end |
#describe_event_bus(params = {}) ⇒ Types::DescribeEventBusResponse
Displays details about an event bus in your account. This can include the external Amazon Web Services accounts that are permitted to write events to your default event bus, and the associated policy. For custom event buses and partner event buses, it displays the name, ARN, policy, state, and creation time.
To enable your account to receive events from other accounts on its default event bus, use [PutPermission].
For more information about partner event buses, see [CreateEventBus].
[1]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutPermission.html [2]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateEventBus.html
1763 1764 1765 1766 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1763 def describe_event_bus(params = {}, = {}) req = build_request(:describe_event_bus, params) req.send_request() end |
#describe_event_source(params = {}) ⇒ Types::DescribeEventSourceResponse
This operation lists details about a partner event source that is shared with your account.
1802 1803 1804 1805 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1802 def describe_event_source(params = {}, = {}) req = build_request(:describe_event_source, params) req.send_request() end |
#describe_partner_event_source(params = {}) ⇒ Types::DescribePartnerEventSourceResponse
An SaaS partner can use this operation to list details about a partner event source that they have created. Amazon Web Services customers do not use this operation. Instead, Amazon Web Services customers can use
- DescribeEventSource][1
-
to see details about a partner event source
that is shared with them.
[1]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeEventSource.html
1840 1841 1842 1843 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1840 def describe_partner_event_source(params = {}, = {}) req = build_request(:describe_partner_event_source, params) req.send_request() end |
#describe_replay(params = {}) ⇒ Types::DescribeReplayResponse
Retrieves details about a replay. Use ‘DescribeReplay` to determine the progress of a running replay. A replay processes events to replay based on the time in the event, and replays them using 1 minute intervals. If you use `StartReplay` and specify an `EventStartTime` and an `EventEndTime` that covers a 20 minute time range, the events are replayed from the first minute of that 20 minute range first. Then the events from the second minute are replayed. You can use `DescribeReplay` to determine the progress of a replay. The value returned for `EventLastReplayedTime` indicates the time within the specified time range associated with the last event replayed.
1901 1902 1903 1904 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1901 def describe_replay(params = {}, = {}) req = build_request(:describe_replay, params) req.send_request() end |
#describe_rule(params = {}) ⇒ Types::DescribeRuleResponse
Describes the specified rule.
DescribeRule does not list the targets of a rule. To see the targets associated with a rule, use [ListTargetsByRule].
[1]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListTargetsByRule.html
1959 1960 1961 1962 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1959 def describe_rule(params = {}, = {}) req = build_request(:describe_rule, params) req.send_request() end |
#disable_rule(params = {}) ⇒ Struct
Disables the specified rule. A disabled rule won’t match any events, and won’t self-trigger if it has a schedule expression.
When you disable a rule, incoming events might continue to match to the disabled rule. Allow a short period of time for changes to take effect.
1991 1992 1993 1994 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 1991 def disable_rule(params = {}, = {}) req = build_request(:disable_rule, params) req.send_request() end |
#enable_rule(params = {}) ⇒ Struct
Enables the specified rule. If the rule does not exist, the operation fails.
When you enable a rule, incoming events might not immediately start matching to a newly enabled rule. Allow a short period of time for changes to take effect.
2023 2024 2025 2026 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2023 def enable_rule(params = {}, = {}) req = build_request(:enable_rule, params) req.send_request() end |
#list_api_destinations(params = {}) ⇒ Types::ListApiDestinationsResponse
Retrieves a list of API destination in the account in the current Region.
2084 2085 2086 2087 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2084 def list_api_destinations(params = {}, = {}) req = build_request(:list_api_destinations, params) req.send_request() end |
#list_archives(params = {}) ⇒ Types::ListArchivesResponse
Lists your archives. You can either list all the archives or you can provide a prefix to match to the archive names. Filter parameters are exclusive.
2149 2150 2151 2152 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2149 def list_archives(params = {}, = {}) req = build_request(:list_archives, params) req.send_request() end |
#list_connections(params = {}) ⇒ Types::ListConnectionsResponse
Retrieves a list of connections from the account.
2208 2209 2210 2211 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2208 def list_connections(params = {}, = {}) req = build_request(:list_connections, params) req.send_request() end |
#list_endpoints(params = {}) ⇒ Types::ListEndpointsResponse
List the global endpoints associated with this account. For more information about global endpoints, see [Making applications Regional-fault tolerant with global endpoints and event replication] in the Amazon EventBridge User Guide .
[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-global-endpoints.html
2283 2284 2285 2286 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2283 def list_endpoints(params = {}, = {}) req = build_request(:list_endpoints, params) req.send_request() end |
#list_event_buses(params = {}) ⇒ Types::ListEventBusesResponse
Lists all the event buses in your account, including the default event bus, custom event buses, and partner event buses.
2339 2340 2341 2342 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2339 def list_event_buses(params = {}, = {}) req = build_request(:list_event_buses, params) req.send_request() end |
#list_event_sources(params = {}) ⇒ Types::ListEventSourcesResponse
You can use this to see all the partner event sources that have been shared with your Amazon Web Services account. For more information about partner event sources, see [CreateEventBus].
[1]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateEventBus.html
2400 2401 2402 2403 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2400 def list_event_sources(params = {}, = {}) req = build_request(:list_event_sources, params) req.send_request() end |
#list_partner_event_source_accounts(params = {}) ⇒ Types::ListPartnerEventSourceAccountsResponse
An SaaS partner can use this operation to display the Amazon Web Services account ID that a particular partner event source name is associated with. This operation is not used by Amazon Web Services customers.
2456 2457 2458 2459 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2456 def list_partner_event_source_accounts(params = {}, = {}) req = build_request(:list_partner_event_source_accounts, params) req.send_request() end |
#list_partner_event_sources(params = {}) ⇒ Types::ListPartnerEventSourcesResponse
An SaaS partner can use this operation to list all the partner event source names that they have created. This operation is not used by Amazon Web Services customers.
2509 2510 2511 2512 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2509 def list_partner_event_sources(params = {}, = {}) req = build_request(:list_partner_event_sources, params) req.send_request() end |
#list_replays(params = {}) ⇒ Types::ListReplaysResponse
Lists your replays. You can either list all the replays or you can provide a prefix to match to the replay names. Filter parameters are exclusive.
2575 2576 2577 2578 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2575 def list_replays(params = {}, = {}) req = build_request(:list_replays, params) req.send_request() end |
#list_rule_names_by_target(params = {}) ⇒ Types::ListRuleNamesByTargetResponse
Lists the rules for the specified target. You can see which of the rules in Amazon EventBridge can invoke a specific target in your account.
The maximum number of results per page for requests is 100.
2631 2632 2633 2634 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2631 def list_rule_names_by_target(params = {}, = {}) req = build_request(:list_rule_names_by_target, params) req.send_request() end |
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists your Amazon EventBridge rules. You can either list all the rules or you can provide a prefix to match to the rule names.
The maximum number of results per page for requests is 100.
ListRules does not list the targets of a rule. To see the targets associated with a rule, use [ListTargetsByRule].
[1]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListTargetsByRule.html
2701 2702 2703 2704 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2701 def list_rules(params = {}, = {}) req = build_request(:list_rules, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Displays the tags associated with an EventBridge resource. In EventBridge, rules and event buses can be tagged.
2732 2733 2734 2735 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2732 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_targets_by_rule(params = {}) ⇒ Types::ListTargetsByRuleResponse
Lists the targets assigned to the specified rule.
The maximum number of results per page for requests is 100.
2851 2852 2853 2854 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2851 def list_targets_by_rule(params = {}, = {}) req = build_request(:list_targets_by_rule, params) req.send_request() end |
#put_events(params = {}) ⇒ Types::PutEventsResponse
Sends custom events to Amazon EventBridge so that they can be matched to rules.
You can batch multiple event entries into one request for efficiency. However, the total entry size must be less than 256KB. You can calculate the entry size before you send the events. For more information, see [Calculating PutEvents event entry size] in the Amazon EventBridge User Guide .
PutEvents accepts the data in JSON format. For the JSON number (integer) data type, the constraints are: a minimum value of -9,223,372,036,854,775,808 and a maximum value of 9,223,372,036,854,775,807.
<note markdown=“1”> PutEvents will only process nested JSON up to 1000 levels deep.
</note>
[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-putevents.html#eb-putevent-size
2924 2925 2926 2927 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2924 def put_events(params = {}, = {}) req = build_request(:put_events, params) req.send_request() end |
#put_partner_events(params = {}) ⇒ Types::PutPartnerEventsResponse
This is used by SaaS partners to write events to a customer’s partner event bus. Amazon Web Services customers do not use this operation.
For information on calculating event batch size, see [Calculating EventBridge PutEvents event entry size] in the *EventBridge User Guide*.
[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-putevent-size.html
2974 2975 2976 2977 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 2974 def put_partner_events(params = {}, = {}) req = build_request(:put_partner_events, params) req.send_request() end |
#put_permission(params = {}) ⇒ Struct
Running ‘PutPermission` permits the specified Amazon Web Services account or Amazon Web Services organization to put events to the specified *event bus*. Amazon EventBridge rules in your account are triggered by these events arriving to an event bus in your account.
For another account to send events to your account, that external account must have an EventBridge rule with your account’s event bus as a target.
To enable multiple Amazon Web Services accounts to put events to your event bus, run ‘PutPermission` once for each of these accounts. Or, if all the accounts are members of the same Amazon Web Services organization, you can run `PutPermission` once specifying `Principal` as “*” and specifying the Amazon Web Services organization ID in `Condition`, to grant permissions to all accounts in that organization.
If you grant permissions using an organization, then accounts in that organization must specify a ‘RoleArn` with proper permissions when they use `PutTarget` to add your account’s event bus as a target. For more information, see [Sending and Receiving Events Between Amazon Web Services Accounts] in the *Amazon EventBridge User Guide*.
The permission policy on the event bus cannot exceed 10 KB in size.
[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eventbridge-cross-account-event-delivery.html
3086 3087 3088 3089 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 3086 def (params = {}, = {}) req = build_request(:put_permission, params) req.send_request() end |
#put_rule(params = {}) ⇒ Types::PutRuleResponse
Creates or updates the specified rule. Rules are enabled by default, or based on value of the state. You can disable a rule using [DisableRule].
A single rule watches for events from a single event bus. Events generated by Amazon Web Services services go to your account’s default event bus. Events generated by SaaS partner services or applications go to the matching partner event bus. If you have custom applications or services, you can specify whether their events go to your default event bus or a custom event bus that you have created. For more information, see [CreateEventBus].
If you are updating an existing rule, the rule is replaced with what you specify in this ‘PutRule` command. If you omit arguments in `PutRule`, the old values for those arguments are not kept. Instead, they are replaced with null values.
When you create or update a rule, incoming events might not immediately start matching to new or updated rules. Allow a short period of time for changes to take effect.
A rule must contain at least an EventPattern or ScheduleExpression. Rules with EventPatterns are triggered when a matching event is observed. Rules with ScheduleExpressions self-trigger based on the given schedule. A rule can have both an EventPattern and a ScheduleExpression, in which case the rule triggers on matching events as well as on a schedule.
When you initially create a rule, you can optionally assign one or more tags to the rule. Tags can help you organize and categorize your resources. You can also use them to scope user permissions, by granting a user permission to access or change only rules with certain tag values. To use the ‘PutRule` operation and assign tags, you must have both the `events:PutRule` and `events:TagResource` permissions.
If you are updating an existing rule, any tags you specify in the ‘PutRule` operation are ignored. To update the tags of an existing rule, use [TagResource] and [UntagResource].
Most services in Amazon Web Services treat : or / as the same character in Amazon Resource Names (ARNs). However, EventBridge uses an exact match in event patterns and rules. Be sure to use the correct ARN characters when creating event patterns so that they match the ARN syntax in the event you want to match.
In EventBridge, it is possible to create rules that lead to infinite loops, where a rule is fired repeatedly. For example, a rule might detect that ACLs have changed on an S3 bucket, and trigger software to change them to the desired state. If the rule is not written carefully, the subsequent change to the ACLs fires the rule again, creating an infinite loop.
To prevent this, write the rules so that the triggered actions do not re-fire the same rule. For example, your rule could fire only if ACLs are found to be in a bad state, instead of after any change.
An infinite loop can quickly cause higher than expected charges. We recommend that you use budgeting, which alerts you when charges exceed your specified limit. For more information, see [Managing Your Costs with Budgets].
To create a rule that filters for management events from Amazon Web Services services, see [Receiving read-only management events from Amazon Web Services services] in the *EventBridge User Guide*.
[1]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_DisableRule.html [2]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateEventBus.html [3]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_TagResource.html [4]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_UntagResource.html [5]: docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/budgets-managing-costs.html [6]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-service-event-cloudtrail.html#eb-service-event-cloudtrail-management
3266 3267 3268 3269 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 3266 def put_rule(params = {}, = {}) req = build_request(:put_rule, params) req.send_request() end |
#put_targets(params = {}) ⇒ Types::PutTargetsResponse
Adds the specified targets to the specified rule, or updates the targets if they are already associated with the rule.
Targets are the resources that are invoked when a rule is triggered.
The maximum number of entries per request is 10.
<note markdown=“1”> Each rule can have up to five (5) targets associated with it at one time.
</note>
For a list of services you can configure as targets for events, see
- EventBridge targets][1
-
in the <i> <i>Amazon EventBridge User
Guide</i> </i>.
Creating rules with built-in targets is supported only in the Amazon Web Services Management Console. The built-in targets are:
-
‘Amazon EBS CreateSnapshot API call`
-
‘Amazon EC2 RebootInstances API call`
-
‘Amazon EC2 StopInstances API call`
-
‘Amazon EC2 TerminateInstances API call`
For some target types, ‘PutTargets` provides target-specific parameters. If the target is a Kinesis data stream, you can optionally specify which shard the event goes to by using the `KinesisParameters` argument. To invoke a command on multiple EC2 instances with one rule, you can use the `RunCommandParameters` field.
To be able to make API calls against the resources that you own, Amazon EventBridge needs the appropriate permissions:
-
For Lambda and Amazon SNS resources, EventBridge relies on resource-based policies.
-
For EC2 instances, Kinesis Data Streams, Step Functions state machines and API Gateway APIs, EventBridge relies on IAM roles that you specify in the ‘RoleARN` argument in `PutTargets`.
For more information, see [Authentication and Access Control] in the Amazon EventBridge User Guide .
If another Amazon Web Services account is in the same region and has granted you permission (using ‘PutPermission`), you can send events to that account. Set that account’s event bus as a target of the rules in your account. To send the matched events to the other account, specify that account’s event bus as the ‘Arn` value when you run `PutTargets`. If your account sends events to another account, your account is charged for each sent event. Each event sent to another account is charged as a custom event. The account receiving the event is not charged. For more information, see [Amazon EventBridge Pricing].
<note markdown=“1”> ‘Input`, `InputPath`, and `InputTransformer` are not available with `PutTarget` if the target is an event bus of a different Amazon Web Services account.
</note>
If you are setting the event bus of another account as the target, and that account granted permission to your account through an organization instead of directly by the account ID, then you must specify a ‘RoleArn` with proper permissions in the `Target` structure. For more information, see [Sending and Receiving Events Between Amazon Web Services Accounts] in the *Amazon EventBridge User Guide*.
<note markdown=“1”> If you have an IAM role on a cross-account event bus target, a ‘PutTargets` call without a role on the same target (same `Id` and `Arn`) will not remove the role.
</note>
For more information about enabling cross-account events, see [PutPermission].
Input, InputPath, and InputTransformer are mutually exclusive and optional parameters of a target. When a rule is triggered due to a matched event:
-
If none of the following arguments are specified for a target, then the entire event is passed to the target in JSON format (unless the target is Amazon EC2 Run Command or Amazon ECS task, in which case nothing from the event is passed to the target).
-
If Input is specified in the form of valid JSON, then the matched event is overridden with this constant.
-
If InputPath is specified in the form of JSONPath (for example, ‘$.detail`), then only the part of the event specified in the path is passed to the target (for example, only the detail part of the event is passed).
-
If InputTransformer is specified, then one or more specified JSONPaths are extracted from the event and used as values in a template that you specify as the input to the target.
When you specify ‘InputPath` or `InputTransformer`, you must use JSON dot notation, not bracket notation.
When you add targets to a rule and the associated rule triggers soon after, new or updated targets might not be immediately invoked. Allow a short period of time for changes to take effect.
This action can partially fail if too many requests are made at the same time. If that happens, ‘FailedEntryCount` is non-zero in the response and each entry in `FailedEntries` provides the ID of the failed target and the error code.
[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-targets.html [2]: docs.aws.amazon.com/eventbridge/latest/userguide/auth-and-access-control-eventbridge.html [3]: aws.amazon.com/eventbridge/pricing/ [4]: docs.aws.amazon.com/eventbridge/latest/userguide/eventbridge-cross-account-event-delivery.html [5]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutPermission.html
3543 3544 3545 3546 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 3543 def put_targets(params = {}, = {}) req = build_request(:put_targets, params) req.send_request() end |
#remove_permission(params = {}) ⇒ Struct
Revokes the permission of another Amazon Web Services account to be able to put events to the specified event bus. Specify the account to revoke by the ‘StatementId` value that you associated with the account when you granted it permission with `PutPermission`. You can find the `StatementId` by using [DescribeEventBus].
[1]: docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeEventBus.html
3583 3584 3585 3586 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 3583 def (params = {}, = {}) req = build_request(:remove_permission, params) req.send_request() end |
#remove_targets(params = {}) ⇒ Types::RemoveTargetsResponse
Removes the specified targets from the specified rule. When the rule is triggered, those targets are no longer be invoked.
<note markdown=“1”> A successful execution of ‘RemoveTargets` doesn’t guarantee all targets are removed from the rule, it means that the target(s) listed in the request are removed.
</note>
When you remove a target, when the associated rule triggers, removed targets might continue to be invoked. Allow a short period of time for changes to take effect.
This action can partially fail if too many requests are made at the same time. If that happens, ‘FailedEntryCount` is non-zero in the response and each entry in `FailedEntries` provides the ID of the failed target and the error code.
The maximum number of entries per request is 10.
3651 3652 3653 3654 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 3651 def remove_targets(params = {}, = {}) req = build_request(:remove_targets, params) req.send_request() end |
#start_replay(params = {}) ⇒ Types::StartReplayResponse
Starts the specified replay. Events are not necessarily replayed in the exact same order that they were added to the archive. A replay processes events to replay based on the time in the event, and replays them using 1 minute intervals. If you specify an ‘EventStartTime` and an `EventEndTime` that covers a 20 minute time range, the events are replayed from the first minute of that 20 minute range first. Then the events from the second minute are replayed. You can use `DescribeReplay` to determine the progress of a replay. The value returned for `EventLastReplayedTime` indicates the time within the specified time range associated with the last event replayed.
3720 3721 3722 3723 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 3720 def start_replay(params = {}, = {}) req = build_request(:start_replay, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified EventBridge resource. Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values. In EventBridge, rules and event buses can be tagged.
Tags don’t have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters.
You can use the ‘TagResource` action with a resource that already has tags. If you specify a new tag key, this tag is appended to the list of tags associated with the resource. If you specify a tag key that is already associated with the resource, the new tag value that you specify replaces the previous value for that tag.
You can associate as many as 50 tags with a resource.
3766 3767 3768 3769 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 3766 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#test_event_pattern(params = {}) ⇒ Types::TestEventPatternResponse
Tests whether the specified event pattern matches the provided event.
Most services in Amazon Web Services treat : or / as the same character in Amazon Resource Names (ARNs). However, EventBridge uses an exact match in event patterns and rules. Be sure to use the correct ARN characters when creating event patterns so that they match the ARN syntax in the event you want to match.
3829 3830 3831 3832 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 3829 def test_event_pattern(params = {}, = {}) req = build_request(:test_event_pattern, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified EventBridge resource. In Amazon EventBridge, rules and event buses can be tagged.
3856 3857 3858 3859 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 3856 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_api_destination(params = {}) ⇒ Types::UpdateApiDestinationResponse
Updates an API destination.
3911 3912 3913 3914 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 3911 def update_api_destination(params = {}, = {}) req = build_request(:update_api_destination, params) req.send_request() end |
#update_archive(params = {}) ⇒ Types::UpdateArchiveResponse
Updates the specified archive.
3983 3984 3985 3986 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 3983 def update_archive(params = {}, = {}) req = build_request(:update_archive, params) req.send_request() end |
#update_connection(params = {}) ⇒ Types::UpdateConnectionResponse
Updates settings for a connection.
4132 4133 4134 4135 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 4132 def update_connection(params = {}, = {}) req = build_request(:update_connection, params) req.send_request() end |
#update_endpoint(params = {}) ⇒ Types::UpdateEndpointResponse
Update an existing endpoint. For more information about global endpoints, see [Making applications Regional-fault tolerant with global endpoints and event replication] in the Amazon EventBridge User Guide .
[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-global-endpoints.html
4221 4222 4223 4224 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 4221 def update_endpoint(params = {}, = {}) req = build_request(:update_endpoint, params) req.send_request() end |
#update_event_bus(params = {}) ⇒ Types::UpdateEventBusResponse
Updates the specified event bus.
4335 4336 4337 4338 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 4335 def update_event_bus(params = {}, = {}) req = build_request(:update_event_bus, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4364 4365 4366 |
# File 'lib/aws-sdk-eventbridge/client.rb', line 4364 def waiter_names [] end |