Class: Aws::EventBridge::Types::CreateConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eventbridge/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_parametersTypes::CreateConnectionAuthRequestParameters

The authorization parameters to use to authorize with the endpoint.

You must include only authorization parameters for the AuthorizationType you specify.



991
992
993
994
995
996
997
998
999
# File 'lib/aws-sdk-eventbridge/types.rb', line 991

class CreateConnectionRequest < Struct.new(
  :name,
  :description,
  :authorization_type,
  :auth_parameters,
  :invocation_connectivity_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#authorization_typeString

The type of authorization to use for the connection.

<note markdown=“1”> OAUTH tokens are refreshed when a 401 or 407 response is returned.

</note>

Returns:

  • (String)


991
992
993
994
995
996
997
998
999
# File 'lib/aws-sdk-eventbridge/types.rb', line 991

class CreateConnectionRequest < Struct.new(
  :name,
  :description,
  :authorization_type,
  :auth_parameters,
  :invocation_connectivity_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the connection to create.

Returns:

  • (String)


991
992
993
994
995
996
997
998
999
# File 'lib/aws-sdk-eventbridge/types.rb', line 991

class CreateConnectionRequest < Struct.new(
  :name,
  :description,
  :authorization_type,
  :auth_parameters,
  :invocation_connectivity_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#invocation_connectivity_parametersTypes::ConnectivityResourceParameters

For connections to private resource endpoints, the parameters to use for invoking the resource endpoint.

For more information, see [Connecting to private resources] in the Amazon EventBridge User Guide .

[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-target-connection-private.html



991
992
993
994
995
996
997
998
999
# File 'lib/aws-sdk-eventbridge/types.rb', line 991

class CreateConnectionRequest < Struct.new(
  :name,
  :description,
  :authorization_type,
  :auth_parameters,
  :invocation_connectivity_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name for the connection to create.

Returns:

  • (String)


991
992
993
994
995
996
997
998
999
# File 'lib/aws-sdk-eventbridge/types.rb', line 991

class CreateConnectionRequest < Struct.new(
  :name,
  :description,
  :authorization_type,
  :auth_parameters,
  :invocation_connectivity_parameters)
  SENSITIVE = []
  include Aws::Structure
end