Class: Aws::EventBridge::Types::DescribeConnectionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eventbridge/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_parametersTypes::ConnectionAuthResponseParameters

The parameters to use for authorization for the connection.



1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
# File 'lib/aws-sdk-eventbridge/types.rb', line 1781

class DescribeConnectionResponse < Struct.new(
  :connection_arn,
  :name,
  :description,
  :invocation_connectivity_parameters,
  :connection_state,
  :state_reason,
  :authorization_type,
  :secret_arn,
  :auth_parameters,
  :creation_time,
  :last_modified_time,
  :last_authorized_time)
  SENSITIVE = []
  include Aws::Structure
end

#authorization_typeString

The type of authorization specified for the connection.



1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
# File 'lib/aws-sdk-eventbridge/types.rb', line 1781

class DescribeConnectionResponse < Struct.new(
  :connection_arn,
  :name,
  :description,
  :invocation_connectivity_parameters,
  :connection_state,
  :state_reason,
  :authorization_type,
  :secret_arn,
  :auth_parameters,
  :creation_time,
  :last_modified_time,
  :last_authorized_time)
  SENSITIVE = []
  include Aws::Structure
end

#connection_arnString

The ARN of the connection retrieved.



1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
# File 'lib/aws-sdk-eventbridge/types.rb', line 1781

class DescribeConnectionResponse < Struct.new(
  :connection_arn,
  :name,
  :description,
  :invocation_connectivity_parameters,
  :connection_state,
  :state_reason,
  :authorization_type,
  :secret_arn,
  :auth_parameters,
  :creation_time,
  :last_modified_time,
  :last_authorized_time)
  SENSITIVE = []
  include Aws::Structure
end

#connection_stateString

The state of the connection retrieved.



1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
# File 'lib/aws-sdk-eventbridge/types.rb', line 1781

class DescribeConnectionResponse < Struct.new(
  :connection_arn,
  :name,
  :description,
  :invocation_connectivity_parameters,
  :connection_state,
  :state_reason,
  :authorization_type,
  :secret_arn,
  :auth_parameters,
  :creation_time,
  :last_modified_time,
  :last_authorized_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A time stamp for the time that the connection was created.



1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
# File 'lib/aws-sdk-eventbridge/types.rb', line 1781

class DescribeConnectionResponse < Struct.new(
  :connection_arn,
  :name,
  :description,
  :invocation_connectivity_parameters,
  :connection_state,
  :state_reason,
  :authorization_type,
  :secret_arn,
  :auth_parameters,
  :creation_time,
  :last_modified_time,
  :last_authorized_time)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description for the connection retrieved.



1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
# File 'lib/aws-sdk-eventbridge/types.rb', line 1781

class DescribeConnectionResponse < Struct.new(
  :connection_arn,
  :name,
  :description,
  :invocation_connectivity_parameters,
  :connection_state,
  :state_reason,
  :authorization_type,
  :secret_arn,
  :auth_parameters,
  :creation_time,
  :last_modified_time,
  :last_authorized_time)
  SENSITIVE = []
  include Aws::Structure
end

#invocation_connectivity_parametersTypes::DescribeConnectionConnectivityParameters

For connections to private resource endpoints. The parameters EventBridge uses to invoke the resource endpoint.

For more information, see [Connecting to private resources] in the Amazon EventBridge User Guide .

[1]: docs.aws.amazon.com/eventbridge/latest/userguide/eb-target-connection-private.html



1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
# File 'lib/aws-sdk-eventbridge/types.rb', line 1781

class DescribeConnectionResponse < Struct.new(
  :connection_arn,
  :name,
  :description,
  :invocation_connectivity_parameters,
  :connection_state,
  :state_reason,
  :authorization_type,
  :secret_arn,
  :auth_parameters,
  :creation_time,
  :last_modified_time,
  :last_authorized_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_authorized_timeTime

A time stamp for the time that the connection was last authorized.



1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
# File 'lib/aws-sdk-eventbridge/types.rb', line 1781

class DescribeConnectionResponse < Struct.new(
  :connection_arn,
  :name,
  :description,
  :invocation_connectivity_parameters,
  :connection_state,
  :state_reason,
  :authorization_type,
  :secret_arn,
  :auth_parameters,
  :creation_time,
  :last_modified_time,
  :last_authorized_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

A time stamp for the time that the connection was last modified.



1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
# File 'lib/aws-sdk-eventbridge/types.rb', line 1781

class DescribeConnectionResponse < Struct.new(
  :connection_arn,
  :name,
  :description,
  :invocation_connectivity_parameters,
  :connection_state,
  :state_reason,
  :authorization_type,
  :secret_arn,
  :auth_parameters,
  :creation_time,
  :last_modified_time,
  :last_authorized_time)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the connection retrieved.



1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
# File 'lib/aws-sdk-eventbridge/types.rb', line 1781

class DescribeConnectionResponse < Struct.new(
  :connection_arn,
  :name,
  :description,
  :invocation_connectivity_parameters,
  :connection_state,
  :state_reason,
  :authorization_type,
  :secret_arn,
  :auth_parameters,
  :creation_time,
  :last_modified_time,
  :last_authorized_time)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnString

The ARN of the secret created from the authorization parameters specified for the connection.



1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
# File 'lib/aws-sdk-eventbridge/types.rb', line 1781

class DescribeConnectionResponse < Struct.new(
  :connection_arn,
  :name,
  :description,
  :invocation_connectivity_parameters,
  :connection_state,
  :state_reason,
  :authorization_type,
  :secret_arn,
  :auth_parameters,
  :creation_time,
  :last_modified_time,
  :last_authorized_time)
  SENSITIVE = []
  include Aws::Structure
end

#state_reasonString

The reason that the connection is in the current connection state.



1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
# File 'lib/aws-sdk-eventbridge/types.rb', line 1781

class DescribeConnectionResponse < Struct.new(
  :connection_arn,
  :name,
  :description,
  :invocation_connectivity_parameters,
  :connection_state,
  :state_reason,
  :authorization_type,
  :secret_arn,
  :auth_parameters,
  :creation_time,
  :last_modified_time,
  :last_authorized_time)
  SENSITIVE = []
  include Aws::Structure
end