Method: Aws::EventBridge::Types::EcsParameters#placement_strategy

Defined in:
lib/aws-sdk-eventbridge/types.rb

#placement_strategyArray<Types::PlacementStrategy>

The placement strategy objects to use for the task. You can specify a maximum of five strategy rules per task.



2480
2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
# File 'lib/aws-sdk-eventbridge/types.rb', line 2480

class EcsParameters < Struct.new(
  :task_definition_arn,
  :task_count,
  :launch_type,
  :network_configuration,
  :platform_version,
  :group,
  :capacity_provider_strategy,
  :enable_ecs_managed_tags,
  :enable_execute_command,
  :placement_constraints,
  :placement_strategy,
  :propagate_tags,
  :reference_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end