Class: Aws::EventBridge::Types::EventBus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eventbridge/types.rb

Overview

An event bus receives events from a source, uses rules to evaluate them, applies any configured input transformation, and routes them to the appropriate target(s). Your account’s default event bus receives events from Amazon Web Services services. A custom event bus can receive events from your custom applications and services. A partner event bus receives events from an event source created by an SaaS partner. These events come from the partners services or applications.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the event bus.



2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
# File 'lib/aws-sdk-eventbridge/types.rb', line 2534

class EventBus < Struct.new(
  :name,
  :arn,
  :description,
  :policy,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time the event bus was created.



2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
# File 'lib/aws-sdk-eventbridge/types.rb', line 2534

class EventBus < Struct.new(
  :name,
  :arn,
  :description,
  :policy,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The event bus description.



2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
# File 'lib/aws-sdk-eventbridge/types.rb', line 2534

class EventBus < Struct.new(
  :name,
  :arn,
  :description,
  :policy,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The time the event bus was last modified.



2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
# File 'lib/aws-sdk-eventbridge/types.rb', line 2534

class EventBus < Struct.new(
  :name,
  :arn,
  :description,
  :policy,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the event bus.



2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
# File 'lib/aws-sdk-eventbridge/types.rb', line 2534

class EventBus < Struct.new(
  :name,
  :arn,
  :description,
  :policy,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#policyString

The permissions policy of the event bus, describing which other Amazon Web Services accounts can write events to this event bus.



2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
# File 'lib/aws-sdk-eventbridge/types.rb', line 2534

class EventBus < Struct.new(
  :name,
  :arn,
  :description,
  :policy,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end