Class: Aws::EventBridge::Types::PutEventsResultEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::EventBridge::Types::PutEventsResultEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eventbridge/types.rb
Overview
Represents the results of an event submitted to an event bus.
If the submission was successful, the entry has the event ID in it. Otherwise, you can use the error code and error message to identify the problem with the entry.
For information about the errors that are common to all actions, see [Common Errors].
[1]: docs.aws.amazon.com/eventbridge/latest/APIReference/CommonErrors.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_code ⇒ String
The error code that indicates why the event submission failed.
-
#error_message ⇒ String
The error message that explains why the event submission failed.
-
#event_id ⇒ String
The ID of the event.
Instance Attribute Details
#error_code ⇒ String
The error code that indicates why the event submission failed.
Retryable errors include:
-
‘ InternalFailure `
The request processing has failed because of an unknown error, exception or failure.
-
‘ ThrottlingException `
The request was denied due to request throttling.
Non-retryable errors include:
-
‘ AccessDeniedException `
You do not have sufficient access to perform this action.
-
InvalidAccountIdExceptionThe account ID provided is not valid.
-
InvalidArgumentA specified parameter is not valid.
-
MalformedDetailThe JSON provided is not valid.
-
RedactionFailureRedacting the CloudTrail event failed.
-
NotAuthorizedForSourceExceptionYou do not have permissions to publish events with this source onto this event bus.
-
NotAuthorizedForDetailTypeExceptionYou do not have permissions to publish events with this detail type onto this event bus.
3946 3947 3948 3949 3950 3951 3952 |
# File 'lib/aws-sdk-eventbridge/types.rb', line 3946 class PutEventsResultEntry < Struct.new( :event_id, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message that explains why the event submission failed.
3946 3947 3948 3949 3950 3951 3952 |
# File 'lib/aws-sdk-eventbridge/types.rb', line 3946 class PutEventsResultEntry < Struct.new( :event_id, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#event_id ⇒ String
The ID of the event.
3946 3947 3948 3949 3950 3951 3952 |
# File 'lib/aws-sdk-eventbridge/types.rb', line 3946 class PutEventsResultEntry < Struct.new( :event_id, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |