Class: Aws::EventBridge::Types::RemoveTargetsResultEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::EventBridge::Types::RemoveTargetsResultEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eventbridge/types.rb
Overview
Represents a target that failed to be removed from a rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_code ⇒ String
The error code that indicates why the target removal failed.
-
#error_message ⇒ String
The error message that explains why the target removal failed.
-
#target_id ⇒ String
The ID of the target.
Instance Attribute Details
#error_code ⇒ String
The error code that indicates why the target removal failed. If the value is ConcurrentModificationException, too many requests were made at the same time.
4479 4480 4481 4482 4483 4484 4485 |
# File 'lib/aws-sdk-eventbridge/types.rb', line 4479 class RemoveTargetsResultEntry < Struct.new( :target_id, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message that explains why the target removal failed.
4479 4480 4481 4482 4483 4484 4485 |
# File 'lib/aws-sdk-eventbridge/types.rb', line 4479 class RemoveTargetsResultEntry < Struct.new( :target_id, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#target_id ⇒ String
The ID of the target.
4479 4480 4481 4482 4483 4484 4485 |
# File 'lib/aws-sdk-eventbridge/types.rb', line 4479 class RemoveTargetsResultEntry < Struct.new( :target_id, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |