Method: Aws::EventBridge::Types::PlacementStrategy#field
- Defined in:
- lib/aws-sdk-eventbridge/types.rb
#field ⇒ String
The field to apply the placement strategy against. For the spread placement strategy, valid values are instanceId (or host, which has the same effect), or any platform or custom attribute that is applied to a container instance, such as attribute:ecs.availability-zone. For the binpack placement strategy, valid values are cpu and memory. For the random placement strategy, this field is not used.
3864 3865 3866 3867 3868 3869 |
# File 'lib/aws-sdk-eventbridge/types.rb', line 3864 class PlacementStrategy < Struct.new( :type, :field) SENSITIVE = [] include Aws::Structure end |